# eric7.Plugins.VcsPlugins.vcsMercurial.CloseheadExtension.closehead

Module implementing the closehead extension interface.

### Global Attributes

None

### Classes

Closehead | Class implementing the strip extension interface.

### Functions

None

## Closehead

Class implementing the strip extension interface.

### Derived from

HgExtension

### Class Attributes

None

### Class Methods

None

### Methods

Closehead | Constructor
hgCloseheads | Public method to close arbitrary heads.

### Static Methods

None

#### Closehead (Constructor)

Closehead(vcs, ui=None)

Constructor

vcs (Hg)
  reference to the Mercurial vcs object
ui (QWidget)
  reference to a UI widget (defaults to None)

#### Closehead.hgCloseheads

hgCloseheads(revisions=None)

Public method to close arbitrary heads.

revisions (str)
  revisions of branch heads to be closed

Up